let params = '',
    prev_params = '';

/**
 * Load in locations via ajax.
 */
let load_locator = function( push_history = 1 ) {
    let locatorEl = jQuery('#locator-list');

    locatorEl.prepend('<div class="locator-loading"><span></span>Loading...</div>');

    // build up params for ajax request, and track prev params to know whether to ignore repeat requests
    prev_params = params;
    params = '';

    // add zip code
    let zip_val = jQuery('#zip').val();
    if ( zip_val.length > 0 ) {
        if (params.length > 0) {
            params = params + '&';
        }
        params = params + 'zip=' + zip_val;
    }

    // add radius
    let radius_val = jQuery('#radius').val();
    if ( radius_val.length > 0 ) {
        if (params.length > 0) {
            params = params + '&';
        }
        params = params + 'radius=' + radius_val;
    }

    // prepend params with the query mark if there are any
    if (params.length > 0) {
        params = '?' + params;
    }

    // build request data for ajax and make the call
    let request_data = {
        'action': 'bt_locator',
        // FILTERS REMOVED 'filter': selected_filters,
        'zip': zip_val,
        'radius': radius_val,
    };

    // check if request is the same as the previous one
    if ( prev_params === params ) {
        jQuery('.locator-loading').remove();
        return false;
    }

    // clear any current markers
    clear_markers();

    // if we're searching, scroll to form top to normalize view
    if ( zip_val ) {
        jQuery('html,body').animate({scrollTop: jQuery('#locator-search').offset().top},'slow');
    }

    // combine request data with initial localized data in setup.php/enqueue_scripts
    jQuery.extend(request_data, request_data, locator_data);

    // add a history state if we're to push history per fn arg
    if (push_history) {
        if (!params.length) {
            // use base path in url for history if no params
            params = window.location.pathname;
        }
        window.history.pushState(request_data, '', params);
    }

    // make the ajax request
    jQuery.post(locator_data.ajax_url, request_data, function(response) {
        locatorEl.html(response);

        // bind clicks on buttons for larger radius
        jQuery('#change-radius').on('click touch', function() {
            let new_radius = jQuery(this).data('new-radius');
            jQuery('#radius').val(new_radius);
            load_locator();
            return false;
        });

        // bind clicks on the list items to open map info windows
        jQuery('#locator-list .location').on('click touch', function() {
            let count = jQuery(this).data('count');
            eval('pin_'+count+'();');
        });

        // universal post-load
        jQuery( document.body ).trigger( 'post-load' );
    });
};

/**
 * Handle history: back/forward nav will set the form values to the history state and load content.
 */
window.onpopstate = function(event) {
    if (event.state != null) {
        // set filter values
        /* FILTERS REMOVED
        if (event.state.filter instanceof Array) {
            // reset the filters
            location_filters.prop('checked', false);
            // check each filter that is in the state data
            event.state.filter.forEach(function(item) {
                jQuery('#filter-'+item).prop('checked', true);
            });
        }
        */
        // set zip code value
        jQuery('#zip').val(event.state.zip);
        // set radius value
        jQuery('#radius').val(event.state.radius);
        // set filter state and load content
        // FILTERS REMOVED filter_option_state();
        load_locator(0);
    }
};


let clear_markers = function () {
    for ( let i = 0; i < gmap.markers.length; i++ ) {
        gmap.markers[i].setMap(null);
    }
    gmap.markers = [];
};


/**
 * Create Google Map and run initial load of locations.
 */
let use_ajax = jQuery('#locator-use-ajax');
if ( use_ajax.length ) {
    use_ajax = true;
} else {
    use_ajax = false;
}

let init_locator = function() {
    // bind form submit to run our ajax function and prevent normal submission
    jQuery('#locator-form').submit( function() {
        load_locator();
        return false;
    });
    // reset radius input if zip changes
    jQuery('#zip').on('change', function() {
        jQuery('#radius').val('10');
    });
    // load google map
    gmap.options = {
        zoom: parseInt(gmap.initial_zoom, 10),
        center: new google.maps.LatLng(gmap.initial_lat,gmap.initial_lng),
        mapTypeId: google.maps.MapTypeId.ROADMAP,
        //scrollwheel: false,
        streetViewControl: false,
        fullscreenControl: true,
        styles: [
            {
                featureType: "poi",
                elementType: "labels",
                stylers: [
                    { visibility: "off" }
                ]
            }
        ]
    };
    gmap.map = new google.maps.Map(document.getElementById("locator-map"), gmap.options);
    gmap.info = new google.maps.InfoWindow( {
        maxWidth: 300,
        pixelOffset: new google.maps.Size(0, 0)
    } );
    gmap.point_bounds = new google.maps.LatLngBounds();
    gmap.marker = {
        url: null,
        size: new google.maps.Size(30, 40),
        origin: new google.maps.Point(0, 0),
        anchor: new google.maps.Point(15, 40),
        scaledSize: new google.maps.Size(30, 40),
    };
    gmap.markers = [];

    if ( use_ajax ) {
        load_locator(0);
    }
};
if ( use_ajax ) {
    init_locator();
}
